@@ -54,11 +54,15 @@ pub(crate) enum SyntaxKind {
     ERROR,      // as well as errors
 
     // composite nodes
-    ROOT,      // The entire file
-    VERSION,   // "version=x\n"
-    ENTRY,     // "opts=foo=blah https://foo.com/bar .*/v?(\d\S+)\.tar\.gz\n"
-    OPTS_LIST, // "opts=foo=blah"
-    OPTION,    // "foo=blah"
+    ROOT,             // The entire file
+    VERSION,          // "version=x\n"
+    ENTRY,            // "opts=foo=blah https://foo.com/bar .*/v?(\d\S+)\.tar\.gz\n"
+    OPTS_LIST,        // "opts=foo=blah"
+    OPTION,           // "foo=blah"
+    URL,              // "https://foo.com/bar"
+    MATCHING_PATTERN, // ".*/v?(\d\S+)\.tar\.gz"
+    VERSION_POLICY,   // "debian"
+    SCRIPT,           // "uupdate"
 }
 
 /// Convert our `SyntaxKind` into the rowan `SyntaxKind`.
@@ -85,4 +89,41 @@ mod tests {
 
         assert_eq!("version=4\n", wf.to_string());
     }
+
+    #[test]
+    fn test_set_version() {
+        let mut wf = super::WatchFile::new(Some(4));
+        assert_eq!(wf.version(), 4);
+
+        wf.set_version(5);
+        assert_eq!(wf.version(), 5);
+        assert_eq!("version=5\n", wf.to_string());
+
+        // Test setting version on a file without version
+        let mut wf = super::WatchFile::new(None);
+        assert_eq!(wf.version(), super::DEFAULT_VERSION);
+
+        wf.set_version(4);
+        assert_eq!(wf.version(), 4);
+        assert_eq!("version=4\n", wf.to_string());
+    }
+
+    #[test]
+    fn test_set_version_on_parsed() {
+        // Test that parsed WatchFiles can be mutated
+        let mut wf: super::WatchFile = "version=4\n".parse().unwrap();
+        assert_eq!(wf.version(), 4);
+
+        wf.set_version(5);
+        assert_eq!(wf.version(), 5);
+        assert_eq!("version=5\n", wf.to_string());
+
+        // Test setting version on a parsed file without version
+        let mut wf: super::WatchFile = "".parse().unwrap();
+        assert_eq!(wf.version(), super::DEFAULT_VERSION);
+
+        wf.set_version(4);
+        assert_eq!(wf.version(), 4);
+        assert_eq!("version=4\n", wf.to_string());
+    }
 }
